==> nextcloud-16.0.9.tar.bz2: nextcloud/apps/privacy/l10n/el.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Ιδιωτικότητα",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Το κέντρο απορρήτου σας δείχνει πού φυλάσσονται τα δεδομένα σας και ποιος μπορεί να έχει πρόσβαση σε αυτά, είτε επειδή μοιραστήκατε μαζί τους είτε επειδή είναι διαχειριστές.",
    "Remove external admin" : "Κατάργηση εξωτερικού διαχειριστή",
    "Add external admin" : "Προσθήκη εξωτερικού διαχειριστή",
    "Your files are not protected by encryption." : "Τα αρχεία σας δεν προστατεύονται με κρυπτογράφηση.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Τα αρχεία σας κρυπτογραφούνται με {linkopen}κρυπτογράφηση-διακομιστή ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ο διακομιστής είναι προστατευμένος με κρυπτογράφηση πλήρους δίσκου.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Τα αρχεία σας κρυπτογραφούνται με {linkopen}κρυπτογράφηση-διακομιστή ↗{linkclose}. Επιπλέον, ο διακομιστής προστατεύεται με κρυπτογράφηση πλήρους δίσκου.",
    "This server is using full-disk-encryption." : "Ο διακομιστής χρησιμοποιεί κρυπτογράφηση πλήρους δίσκου.",
    "Change data location" : "Αλλαγή θέσης δεδομένων",
    "Your data is located in: " : "Τα δεδομένα σας βρίσκονται σε:",
    "The admin hasn't selected the location of the server yet." : "Ο διαχειριστής δεν έχει επιλέξει ακόμη την τοποθεσία του διακομιστή.",
    "Please select a country" : "Παρακαλώ επιλέξτε μια χώρα",
    "You don't have any shares with individual users." : "Δεν έχετε μερίδια με μεμονωμένους χρήστες.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Ηνωμένα Αραβικά Εμιράτα",
    "Afghanistan" : "Αφγανιστάν",
    "Albania" : "Αλβανία",
    "Armenia" : "Αρμενία",
    "Angola" : "Αγκόλα",
    "Argentina" : "Αργεντινή",
    "Austria" : "Αυστρία",
    "Australia" : "Αυστραλία",
    "Azerbaijan" : "Αζερμπαϊτζάν",
    "Bosnia and Herzegowina" : "Bosnia and Herzegowina",
    "Bangladesh" : "Μπαγκλαντές ",
    "Belgium" : "Βέλγιο",
    "Burkina Faso" : "Μπουρκίνα Φάσο",
    "Bulgaria" : "Βουλγαρία",
    "Burundi" : "Μπουρούντι",
    "Benin" : "Μπενίν",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Βραζιλία",
    "Bahamas" : "Μπαχάμες",
    "Bhutan" : "Μπουτάν",
    "Botswana" : "Μποτσουάνα",
    "Belarus" : "Λευκορωσία",
    "Belize" : "Μπελίσε",
    "Canada" : "Καναδάς",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Δημοκρατία Κεντρικής Αφρικής",
    "Congo" : "Κονγκό",
    "Switzerland" : "Ελβετία",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Chile" : "Χιλή",
    "Cameroon" : "Καμερούν",
    "China" : "Κίνα",
    "Colombia" : "Κολομβία",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Κούβα",
    "Cyprus" : "Κύπρος",
    "Czech" : "Τσέχικα",
    "Germany" : "Γερμανία",
    "Djibouti" : "Djibouti",
    "Denmark" : "Δανία",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Αλγερία",
    "Ecuador" : "Εκουαδόρ",
    "Estonia" : "Εσθονία",
    "Egypt" : "Αίγυπτος",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Ισπανία",
    "Ethiopia" : "Αιθιοπία",
    "Finland" : "Φινλανδία",
    "Fiji" : "Φίτζι",
    "Falkland Islands" : "Νήσοι Φώκλαντ",
    "France" : "Γαλλία",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Greenland",
    "Gambia" : "Γκάμπια",
    "Guinea" : "Γουϊνέα",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ελλάδα",
    "Guatemala" : "Γουατεμάλα",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Κροατία",
    "Haiti" : "Haiti",
    "Hungary" : "Ουγγαρία",
    "Indonesia" : "Ινδονησία",
    "Ireland" : "Ιρλανδία",
    "Israel" : "Ισραήλ",
    "India" : "Ινδία",
    "Iraq" : "Ιράκ",
    "Iran" : "Iran",
    "Iceland" : "Ισλανδία",
    "Italy" : "Ιταλία",
    "Jamaica" : "Τζαμάικα",
    "Jordan" : "Ιορδανία",
    "Japan" : "Ιαπωνία",
    "Kenya" : "Κένυα",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "κουβέιτ",
    "Kazakhstan" : "Καζακστάν",
    "Laos" : "Laos",
    "Lebanon" : "Λίβανος",
    "Sri Lanka" : "Σρι Λάνκα",
    "Liberia" : "Λιβερία",
    "Lesotho" : "Λεσότο",
    "Lithuania" : "Λιθουανία",
    "Luxembourg" : "Λουξεμβούργο",
    "Latvia" : "Λετονία",
    "Libya" : "Λιβύη",
    "Morocco" : "Μαρόκο",
    "Moldova" : "Moldova",
    "Montenegro" : "Μαυροβούνιο",
    "Madagascar" : "Μαδαγασκάρη",
    "Macedonia" : "Δημοκρατία της Βόρειας Μακεδονίας",
    "Mali" : "Μάλι",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Μογγολία",
    "Mauritania" : "Μαυριτανία",
    "Malawi" : "Μαλάουι",
    "Mexico" : "Μεξικό",
    "Malaysia" : "Μαλαισία",
    "Mozambique" : "Μοζαμβίκη",
    "Namibia" : "Ναμίμπια",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Νίγηρα",
    "Nigeria" : "Νιγηρία",
    "Nicaragua" : "Νικαράγουα",
    "Netherlands" : "Ολλανδία",
    "Norway" : "Νορβηγία",
    "Nepal" : "Νεπάλ",
    "New Zealand" : "Νέα Ζηλανδία",
    "Oman" : "Ομάν",
    "Panama" : "Παναμάς",
    "Peru" : "Περού",
    "Papua New Guinea" : "Παπούα Νέα Γουινέα",
    "Philippines" : "Φιλιππίνες",
    "Pakistan" : "Πακιστάν",
    "Poland" : "Πολωνία",
    "Puerto Rico" : "Πόρτο Ρίκο",
    "Portugal" : "Πορτογαλία",
    "Paraguay" : "Παραγουάη",
    "Qatar" : "Κατάρ",
    "Romania" : "Ρουμανία",
    "Serbia" : "Σερβία",
    "Russia" : "Russia",
    "Rwanda" : "Ρουάντα",
    "Saudi Arabia" : "Σαουδική Αραβία",
    "Solomon Islands" : "Νησιά Σολομώντα",
    "Sudan" : "Σουδάν",
    "Sweden" : "Σουηδία",
    "Singapore" : "Σιγκαπούρη",
    "Slovenia" : "Σλοβενία",
    "Slovakia" : "Σλοβακία",
    "Sierra Leone" : "Σιέρα Λεόνε",
    "Senegal" : "Σενεγάλη",
    "Somalia" : "Σομαλία",
    "Suriname" : "Σουρινάμ",
    "South Sudan" : "Νότιο Σουδάν",
    "El Salvador" : "Ελ Σαλβαδόρ",
    "Syria" : "Syria",
    "Swaziland" : "Σουαζιλάνδη",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Ταϊλάνδη",
    "Tajikistan" : "Tajikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Τουρκμενιστάν",
    "Tunisia" : "Τυνησία",
    "Turkey" : "Τουρκία",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Taiwan" : "Ταϊβάν",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ουκρανία",
    "Uganda" : "Ουγκάντα",
    "United States" : "Ηνωμένες πολιτείες",
    "Uruguay" : "Ουρουγουάη",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Βανουάτου",
    "Yemen" : "Υεμένη",
    "South Africa" : "Νότιος Αφρική",
    "Zambia" : "Ζάμπια",
    "Zimbabwe" : "Ζιμπάμπουε",
    "Your Nextcloud account" : "Ο Nextcloud λογαριασμός σας",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Τα δεδομένα σας αντιπροσωπεύουν ποιοι είστε και μπορείτε εύκολα να καταχραστείτε. Εμείς στο Nextcloud πιστεύουμε ότι έχετε το δικαίωμα να αποφασίσετε τι συμβαίνει με τα δεδομένα σας. Το Nextcloud προστατεύει τα δικαιώματά σας όπως ορίζονται στο Manifesto δεδομένων χρήστη!",
    "User Data Manifesto 2.0" : "Δεδομενα Χρήστη Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Καθορισμός βασικών δικαιωμάτων για τους ανθρώπους να ελέγχουν τα δικά τους δεδομένα στην εποχή του διαδικτύου",
    "Control" : "Έλεγχος",
    "over user data access" : "πρόσβαση σε δεδομένα χρήστη",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Τα δεδομένα που αποστέλλονται ρητά και προφορικά από έναν χρήστη πρέπει να βρίσκονται υπό τον απόλυτο έλεγχο του χρήστη. Οι χρήστες θα πρέπει να έχουν τη δυνατότητα να αποφασίζουν σε ποιον θα χορηγούν άμεση πρόσβαση στα δεδομένα τους και με ποια δικαιώματα και άδειες θα πρέπει να παρέχεται τέτοια πρόσβαση.",
    "Knowledge" : "Γνώση",
    "of how the data is stored" : "πώς αποθηκεύονται τα δεδομένα",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Όταν τα δεδομένα μεταφορτώνονται σε συγκεκριμένο πάροχο υπηρεσιών, οι χρήστες πρέπει να ενημερώνονται σχετικά με το πού αποθηκεύει ο συγκεκριμένος πάροχος τα δεδομένα, πόσο καιρό, σε ποια δικαιοδοσία ανήκει ο συγκεκριμένος πάροχος και ποιοι νόμοι ισχύουν.",
    "Freedom" : "Ελευθερία",
    "to choose a platform" : "για να επιλέξετε μια πλατφόρμα",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Οι χρήστες θα πρέπει πάντα να μπορούν να εξαγάγουν τα δεδομένα τους από την υπηρεσία ανά πάσα στιγμή χωρίς να αντιμετωπίζουν κανένα κλείδωμα. Απαιτούνται ανοικτά πρότυπα για τα μορφότυπα και τα πρωτόκολλα.",
    "Learn more ↗" : "Μάθετε περισσότερα ↗",
    "Where is your data?" : "Που βρίσκονται τα δεδομένα σας;",
    "Who has access to your data?" : "Ποιός έχει πρόσβαση στα δεδομένα σας;",
    "Administrators" : "Διαχειριστές",
    "People you shared with" : "Άτομα με κοινή χρήση",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Read the privacy policy." : "Διαβάστε την πολιτική απορρήτου.",
    "Encryption" : "Κρυπτογράφηση"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/privacy/l10n/el.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Ιδιωτικότητα",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Το κέντρο απορρήτου σας δείχνει πού φυλάσσονται τα δεδομένα σας και ποιος μπορεί να έχει πρόσβαση σε αυτά, είτε επειδή μοιραστήκατε μαζί τους είτε επειδή είναι διαχειριστές.",
    "Administrators" : "Διαχειριστές",
    "Add external admin" : "Προσθήκη εξωτερικού διαχειριστή",
    "Cancel" : "Ακύρωση",
    "Add" : "Προσθήκη",
    "Name of external admin" : "Όνομα εξωτερικού διαχειριστή",
    "Encryption" : "Κρυπτογράφηση",
    "Edit" : "Επεξεργασία",
    "This server is using full-disk-encryption." : "Ο διακομιστής χρησιμοποιεί κρυπτογράφηση πλήρους δίσκου.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Τα αρχεία που βρίσκονται σε εξωτερικούς αποθηκευτικούς χώρους ενδέχεται να κρυπτογραφηθούν χρησιμοποιώντας {linkopen}server-side-encryption ↗{linkclose} με κύριο κλειδί με βάση τη διαμόρφωσή τους.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Τα αρχεία σας που βρίσκονται σε εξωτερικούς αποθηκευτικούς χώρους ενδέχεται να κρυπτογραφηθούν χρησιμοποιώντας {linkopen}server-side-encryption ↗{linkclose} με ένα μεμονωμένο κλειδί με βάση τη διαμόρφωσή τους.",
    "Additionally, this server is protected with full-disk-encryption." : "Επιπλέον, αυτός ο διακομιστής προστατεύεται με κρυπτογράφηση πλήρους δίσκου.",
    "This server is protected with full-disk-encryption." : "Ο διακομιστής είναι προστατευμένος με κρυπτογράφηση πλήρους δίσκου.",
    "Your files are not protected by encryption." : "Τα αρχεία σας δεν προστατεύονται με κρυπτογράφηση.",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Who has access to your data?" : "Ποιός έχει πρόσβαση στα δεδομένα σας;",
    "Where is your data?" : "Πού βρίσκονται τα δεδομένα σας;",
    "Your data is located in:" : "Τα δεδομένα σας βρίσκονται σε:",
    "Change data location" : "Αλλαγή θέσης δεδομένων",
    "Region" : "Περιοχή",
    "Please select a region" : "Επιλέξτε περιοχή",
    "User Data Manifesto 2.0" : "Δεδομενα Χρήστη Manifesto 2.0",
    "Control" : "Έλεγχος",
    "over user data access" : "πρόσβαση σε δεδομένα χρήστη",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Τα δεδομένα που αποστέλλονται ρητά και προφορικά από έναν χρήστη πρέπει να βρίσκονται υπό τον απόλυτο έλεγχο του χρήστη. Οι χρήστες θα πρέπει να έχουν τη δυνατότητα να αποφασίζουν σε ποιον θα χορηγούν άμεση πρόσβαση στα δεδομένα τους και με ποια δικαιώματα και άδειες θα πρέπει να παρέχεται τέτοια πρόσβαση.",
    "Knowledge" : "Γνώση",
    "of how the data is stored" : "πώς αποθηκεύονται τα δεδομένα",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Όταν τα δεδομένα μεταφορτώνονται σε συγκεκριμένο πάροχο υπηρεσιών, οι χρήστες πρέπει να ενημερώνονται σχετικά με το πού αποθηκεύει ο συγκεκριμένος πάροχος τα δεδομένα, πόσο καιρό, σε ποια δικαιοδοσία ανήκει ο συγκεκριμένος πάροχος και ποιοι νόμοι ισχύουν.",
    "Freedom" : "Ελευθερία",
    "to choose a platform" : "για να επιλέξετε μια πλατφόρμα",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Οι χρήστες θα πρέπει πάντα να μπορούν να εξαγάγουν τα δεδομένα τους από την υπηρεσία ανά πάσα στιγμή χωρίς να αντιμετωπίζουν κανένα κλείδωμα. Απαιτούνται ανοικτά πρότυπα για τα μορφότυπα και τα πρωτόκολλα.",
    "Learn more ↗" : "Μάθετε περισσότερα ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Τα δεδομένα σας αντιπροσωπεύουν ποιοι είστε και μπορείτε εύκολα να καταχραστείτε. Εμείς στο Nextcloud πιστεύουμε ότι έχετε το δικαίωμα να αποφασίσετε τι συμβαίνει με τα δεδομένα σας. Το Nextcloud προστατεύει τα δικαιώματά σας όπως ορίζονται στο Manifesto δεδομένων χρήστη!",
    "Somaliland" : "Somaliland",
    "Andorra" : "Ανδόρα",
    "United Arab Emirates" : "Ηνωμένα Αραβικά Εμιράτα",
    "Afghanistan" : "Αφγανιστάν",
    "Antigua and Barbuda" : "Αντίκουα και Μπαρμπούντα",
    "Anguilla" : "Anguilla",
    "Albania" : "Αλβανία",
    "Armenia" : "Αρμενία",
    "Angola" : "Αγκόλα",
    "Antarctica" : "Ανταρκτική",
    "Argentina" : "Αργεντινή",
    "American Samoa" : "Αμερικανική Σαμόα",
    "Austria" : "Αυστρία",
    "Australia" : "Αυστραλία",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Αζερμπαϊτζάν",
    "Bosnia and Herzegovina" : "Βοσνία και Ερζεγοβίνη",
    "Barbados" : "Μπαρμπάντος",
    "Bangladesh" : "Μπαγκλαντές",
    "Belgium" : "Βέλγιο",
    "Burkina Faso" : "Μπουρκίνα Φάσο",
    "Bulgaria" : "Βουλγαρία",
    "Bahrain" : "Μπαχρέιν",
    "Burundi" : "Μπουρούντι",
    "Benin" : "Μπενίν",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Βερμούδα",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Βραζιλία",
    "Bahamas" : "Μπαχάμες",
    "Bhutan" : "Μπουτάν",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Μποτσουάνα",
    "Belarus" : "Λευκορωσία",
    "Belize" : "Μπελίσε",
    "Canada" : "Καναδάς",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Δημοκρατία Κεντρικής Αφρικής",
    "Congo" : "Κονγκό",
    "Switzerland" : "Ελβετία",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Χιλή",
    "Cameroon" : "Καμερούν",
    "China" : "Κίνα",
    "Colombia" : "Κολομβία",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Κούβα",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Νησί των Χριστουγέννων",
    "Cyprus" : "Κύπρος",
    "Czech" : "Τσέχικα",
    "Germany" : "Γερμανία",
    "Djibouti" : "Djibouti",
    "Denmark" : "Δανία",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Αλγερία",
    "Ecuador" : "Εκουαδόρ",
    "Estonia" : "Εσθονία",
    "Egypt" : "Αίγυπτος",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Ισπανία",
    "Ethiopia" : "Αιθιοπία",
    "Finland" : "Φινλανδία",
    "Fiji" : "Φίτζι",
    "Falkland Islands" : "Νήσοι Φώκλαντ",
    "Micronesia" : "Μικρονησία",
    "Faroe Islands" : "Νησιά Φερόε",
    "France" : "Γαλλία",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Grenada" : "Γρενάδα",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Γκάμπια",
    "Guinea" : "Γουϊνέα",
    "Guadeloupe" : "Γουαδελούπη",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ελλάδα",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Γουατεμάλα",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Κροατία",
    "Haiti" : "Haiti",
    "Hungary" : "Ουγγαρία",
    "Indonesia" : "Ινδονησία",
    "Ireland" : "Ιρλανδία",
    "Israel" : "Ισραήλ",
    "Isle of Man" : "Isle of Man",
    "India" : "Ινδία",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Ιράκ",
    "Iran" : "Iran",
    "Iceland" : "Ισλανδία",
    "Italy" : "Ιταλία",
    "Jamaica" : "Τζαμάικα",
    "Jordan" : "Ιορδανία",
    "Japan" : "Ιαπωνία",
    "Kenya" : "Κένυα",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comores" : "Κομόρες",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "Κουβέιτ",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Καζακστάν",
    "Laos" : "Laos",
    "Lebanon" : "Λίβανος",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Λιχτενστάιν",
    "Sri Lanka" : "Σρι Λάνκα",
    "Liberia" : "Λιβερία",
    "Lesotho" : "Λεσότο",
    "Lithuania" : "Λιθουανία",
    "Luxembourg" : "Λουξεμβούργο",
    "Latvia" : "Λετονία",
    "Libya" : "Λιβύη",
    "Morocco" : "Μαρόκο",
    "Monaco" : "Μονακό",
    "Moldova" : "Moldova",
    "Montenegro" : "Μαυροβούνιο",
    "Saint Martin" : "Άγιος Μαρτίνος",
    "Madagascar" : "Μαδαγασκάρη",
    "Marshall Islands" : "Marshall Islands",
    "Macedonia" : "Δημοκρατία της Βόρειας Μακεδονίας",
    "Mali" : "Μάλι",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Μογγολία",
    "Macao" : "Μακάο",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Mauritania" : "Μαυριτανία",
    "Montserrat" : "Montserrat",
    "Malta" : "Μάλτα",
    "Mauritius" : "Μαυρίκιος",
    "Maldives" : "Μαλδίβες",
    "Malawi" : "Μαλάουι",
    "Mexico" : "Μεξικό",
    "Malaysia" : "Μαλαισία",
    "Mozambique" : "Μοζαμβίκη",
    "Namibia" : "Ναμίμπια",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Νίγηρα",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Νιγηρία",
    "Nicaragua" : "Νικαράγουα",
    "Netherlands" : "Ολλανδία",
    "Norway" : "Νορβηγία",
    "Nepal" : "Νεπάλ",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Νέα Ζηλανδία",
    "Oman" : "Ομάν",
    "Panama" : "Παναμάς",
    "Peru" : "Περού",
    "French Polynesia" : "Γαλλική Πολυνησία",
    "Papua New Guinea" : "Παπούα Νέα Γουινέα",
    "Philippines" : "Φιλιππίνες",
    "Pakistan" : "Πακιστάν",
    "Poland" : "Πολωνία",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Πόρτο Ρίκο",
    "Palestine" : "Παλαιστίνη",
    "Portugal" : "Πορτογαλία",
    "Palau" : "Palau",
    "Paraguay" : "Παραγουάη",
    "Qatar" : "Κατάρ",
    "Réunion" : "Réunion",
    "Romania" : "Ρουμανία",
    "Serbia" : "Σερβία",
    "Russia" : "Russia",
    "Rwanda" : "Ρουάντα",
    "Saudi Arabia" : "Σαουδική Αραβία",
    "Solomon Islands" : "Νησιά Σολομώντα",
    "Seychelles" : "Σεϊχέλες",
    "Sudan" : "Σουδάν",
    "Sweden" : "Σουηδία",
    "Singapore" : "Σιγκαπούρη",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Σλοβενία",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Σλοβακία",
    "Sierra Leone" : "Σιέρα Λεόνε",
    "San Marino" : "Σαν Μαρίνο",
    "Senegal" : "Σενεγάλη",
    "Somalia" : "Σομαλία",
    "Suriname" : "Σουρινάμ",
    "South Sudan" : "Νότιο Σουδάν",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "Ελ Σαλβαδόρ",
    "Sint Maarten" : "Άγιος Μαρτίνος (Sint Maarten)",
    "Syria" : "Syria",
    "Swaziland" : "Σουαζιλάνδη",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Ταϊλάνδη",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Τουρκμενιστάν",
    "Tunisia" : "Τυνησία",
    "Tonga" : "Tonga",
    "Turkey" : "Τουρκία",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Τουβάλου",
    "Taiwan" : "Ταϊβάν",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ουκρανία",
    "Uganda" : "Ουγκάντα",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States" : "Ηνωμένες πολιτείες",
    "Uruguay" : "Ουρουγουάη",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Παρθένοι Νήσοι (Βρετανία)",
    "Virgin Islands (U.S.)" : "Παρθένοι Νήσοι (ΗΠΑ)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Βανουάτου",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Σαμόα",
    "Yemen" : "Υεμένη",
    "Mayotte" : "Mayotte",
    "South Africa" : "Νότιος Αφρική",
    "Zambia" : "Ζάμπια",
    "Zimbabwe" : "Ζιμπάμπουε",
    "The admin has not selected the location of the server yet." : "Ο διαχειριστής δεν έχει επιλέξει ακόμη την τοποθεσία του διακομιστή.",
    "You don't have any shares with individual users." : "Δεν έχετε μερίδια με μεμονωμένους χρήστες.",
    "Your %s account" : "O %s λογαριασμός σας",
    "Defining basic rights for people to control their own data in the internet age" : "Καθορισμός βασικών δικαιωμάτων για τους ανθρώπους να ελέγχουν τα δικά τους δεδομένα στην εποχή του διαδικτύου",
    "People you shared with" : "Άτομα με κοινή χρήση",
    "Read the privacy policy." : "Διαβάστε την πολιτική απορρήτου."
},
"nplurals=2; plural=(n != 1);");
